import { EventEmitter } from 'node:events';
import type { ReadyFunctionArg } from 'get-ready';
import { Ready } from 'ready-callback';
import { EggConsoleLogger } from 'egg-logger';
import type { Fun } from './utils/index.js';
import type { EggCore } from './egg.js';
export interface ILifecycleBoot {
    fullPath?: string;
    /**
     * Ready to call configDidLoad,
     * Config, plugin files are referred,
     * this is the last chance to modify the config.
     */
    configWillLoad?(): void;
    /**
     * Config, plugin files have loaded
     */
    configDidLoad?(): void;
    /**
     * All files have loaded, start plugin here
     */
    didLoad?(): Promise<void>;
    /**
     * All plugins have started, can do some thing before app ready
     */
    willReady?(): Promise<void>;
    /**
     * Worker is ready, can do some things,
     * don't need to block the app boot
     */
    didReady?(err?: Error): Promise<void>;
    /**
     * Server is listening
     */
    serverDidReady?(): Promise<void>;
    /**
     * Do some thing before app close
     */
    beforeClose?(): Promise<void>;
}
export type BootImplClass<T = ILifecycleBoot> = new (...args: any[]) => T;
export interface LifecycleOptions {
    baseDir: string;
    app: EggCore;
    logger: EggConsoleLogger;
}
export declare class Lifecycle extends EventEmitter {
    #private;
    loadReady: Ready;
    bootReady: Ready;
    options: LifecycleOptions;
    readyTimeout: number;
    constructor(options: Partial<LifecycleOptions>);
    ready(): Promise<void>;
    ready(flagOrFunction: ReadyFunctionArg): void;
    get app(): EggCore;
    get logger(): EggConsoleLogger<import("egg-logger").LoggerOptions>;
    get timing(): import("./index.js").Timing;
    legacyReadyCallback(name: string, opt?: object): (...args: any[]) => void;
    addBootHook(bootHootOrBootClass: BootImplClass | ILifecycleBoot): void;
    addFunctionAsBootHook<T = EggCore>(hook: (app: T) => void): void;
    /**
     * init boots and trigger config did config
     */
    init(): void;
    registerBeforeStart(scope: Fun, name: string): void;
    registerBeforeClose(fn: Fun): void;
    close(): Promise<void>;
    triggerConfigWillLoad(): void;
    triggerConfigDidLoad(): void;
    triggerDidLoad(): void;
    triggerWillReady(): void;
    triggerDidReady(err?: Error): Promise<void>;
    triggerServerDidReady(): Promise<void>;
}
